package cn.com.qmth.dp.examcloud.oe.modules.findreduplicatequestion;

import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

import org.apache.commons.collections4.CollectionUtils;
import org.apache.poi.xssf.usermodel.XSSFRow;
import org.apache.poi.xssf.usermodel.XSSFSheet;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.jdbc.core.BeanPropertyRowMapper;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Service;

import cn.com.qmth.dp.examcloud.oe.entity.question.Course;
import cn.com.qmth.dp.examcloud.oe.multithread.Producer;

@Service
public class ExportQuesReduplicateProducer extends Producer {

    @Autowired
    private JdbcTemplate jdbcTemplate;

    @Override
    protected void produce(Map<String, Object> param) throws Exception {
        String dir = (String) param.get("dir");
        String mode = (String) param.get("mode");
        Long rootOrgId = (Long) param.get("rootOrgId");

        List<Course> cs = null;
        if ("db".equals(mode)) {
            cs = getCourseByDb(rootOrgId);
        } else if ("file".equals(mode)) {
            cs = getCourseByFile(dir);
        }
        if (CollectionUtils.isEmpty(cs)) {
            System.out.println("*******没有科目");
            return;
        }
        System.out.println("***********courseCount:" + cs.size());
        if (CollectionUtils.isNotEmpty(cs)) {
            for (Course c : cs) {
                offer(c);
            }
        }
        System.out.println("***********courseCount:" + cs.size());
    }

    private List<Course> getCourseByDb(Long rootOrgId) {
        String sql = "select t.* from ec_b_course t where t.root_org_id=" + rootOrgId;
        RowMapper<Course> rowMapper = new BeanPropertyRowMapper<Course>(Course.class);
        List<Course> ret = jdbcTemplate.query(sql, rowMapper);
        return ret;
    }

    private List<Course> getCourseByFile(String dir) {
        List<Course> list = new ArrayList<>();
        XSSFWorkbook wb = null;
        FileInputStream in = null;
        try {
            File file = new File(dir + "subject_info.xlsx");
            in = new FileInputStream(file);
            wb = new XSSFWorkbook(in);
            XSSFSheet sheet = wb.getSheetAt(0);
            int rows = sheet.getLastRowNum();
            for (int i = 1; i <= rows; i++) {
                Course c = new Course();
                XSSFRow row = sheet.getRow(i);
                String ecCode = row.getCell(0).getStringCellValue().trim();
                String name = row.getCell(2).getStringCellValue().trim();
                c.setCode(ecCode);
                c.setName(name);
                list.add(c);

            }
        } catch (IOException e) {
            throw new RuntimeException(e);
        } finally {

            if (wb != null) {
                try {
                    wb.close();
                } catch (IOException e) {
                }
            }
            if (in != null) {
                try {
                    in.close();
                } catch (IOException e) {
                }
            }
        }
        return list;
    }

}
